==> ckan-2.8.5.tar.gz: ckan-2.8.5/ckan/public/base/i18n/bg.js <==
{
  "": {
    "domain": "ckan", 
    "lang": "bg", 
    "plural-forms": "nplurals=2; plural=(n != 1);"
  }, 
  "%(color)s shirt": [
    "%(color)s shirts", 
    "", 
    ""
  ], 
  "%(num)d item": [
    "%(num)d items", 
    "", 
    ""
  ], 
  "%(num)d missing translation": [
    "%(num)d missing translations", 
    "", 
    ""
  ], 
  "Add Filter": [
    null, 
    "Добави филтър "
  ], 
  "An Error Occurred": [
    null, 
    "Възникна грешка"
  ], 
  "Are you sure you want to perform this action?": [
    null, 
    "Сигурни ли сте, че искате да извършите това действие?"
  ], 
  "Cancel": [
    null, 
    "Отказ"
  ], 
  "Confirm": [
    null, 
    "Потвърждаване"
  ], 
  "Edit": [
    null, 
    "Редакция"
  ], 
  "Failed to load data API information": [
    null, 
    "Неуспешно зареждане на информация за API на данните"
  ], 
  "File": [
    null, 
    "Файл"
  ], 
  "Follow": [
    null, 
    "Следване"
  ], 
  "Hide": [
    null, 
    "Скриване"
  ], 
  "Image": [
    null, 
    "Изображение"
  ], 
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters", 
    "", 
    ""
  ], 
  "Link": [
    null, 
    "Връзка"
  ], 
  "Link to a URL on the internet (you can also link to an API)": [
    null, 
    "Посочване на връзка към URL адрес в интернет (можете също така да посочите връзка към API)"
  ], 
  "Loading...": [
    null, 
    "Зареждане...."
  ], 
  "No matches found": [
    null, 
    "Няма намерени съвпадения"
  ], 
  "Please Confirm Action": [
    null, 
    "Моля, потвърдете действието"
  ], 
  "Remove": [
    null, 
    "Премахване"
  ], 
  "Resource uploaded": [
    null, 
    "Ресурсът е качен"
  ], 
  "Save order": [
    null, 
    "Запазване на подредбата"
  ], 
  "Saving...": [
    null, 
    "Запазване..."
  ], 
  "Show more": [
    null, 
    "Показване на още"
  ], 
  "Start typing…": [
    null, 
    "Започнете да пишете..."
  ], 
  "There are unsaved modifications to this form": [
    null, 
    "Има незапазени промени в този формуляр"
  ], 
  "There is no API data to load for this resource": [
    null, 
    "Няма информация в API за този ресурс"
  ], 
  "URL": [
    null, 
    "URL адрес"
  ], 
  "Unable to authenticate upload": [
    null, 
    "Неуспешна проверката за автентичност на качения файл"
  ], 
  "Unable to get data for uploaded file": [
    null, 
    "Неуспешно зареждане на информацията за качения файл"
  ], 
  "Unable to upload file": [
    null, 
    "Неуспешно качване на файл"
  ], 
  "Unfollow": [
    null, 
    "Прекратяване на следването"
  ], 
  "Upload": [
    null, 
    "Качване"
  ], 
  "Upload a file": [
    null, 
    "Качване на файл"
  ], 
  "Upload a file on your computer": [
    null, 
    "Качване файл от Вашия компютър"
  ], 
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null, 
    "В момента качвате файл. Сигурни ли сте, че искате да излезете от страницата и да прекъснете качването?"
  ], 
  "bar": [
    "bars", 
    "", 
    ""
  ], 
  "no %(attr)s translation": [
    "no %(attr)s translations", 
    "", 
    ""
  ], 
  "no translation": [
    "no translations", 
    "", 
    ""
  ]
}

==> ckan-2.9.9.tar.gz: ckan-2.9.9/ckan/public/base/i18n/bg.js <==
{
  "": {
    "domain": "ckan",
    "lang": "bg",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "Add Filter": [
    null,
    "Добави филтър "
  ],
  "An Error Occurred": [
    null,
    "Възникна грешка"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Сигурни ли сте, че искате да извършите това действие?"
  ],
  "Cancel": [
    null,
    "Отказ"
  ],
  "Confirm": [
    null,
    "Потвърждаване"
  ],
  "Could not load view": [
    null,
    "Не можахме да заредим изгледа"
  ],
  "Edit": [
    null,
    "Редакция"
  ],
  "Failed to load data API information": [
    null,
    "Неуспешно зареждане на информация за API на данните"
  ],
  "File": [
    null,
    "Файл"
  ],
  "Filters": [
    null,
    "Филтри"
  ],
  "Follow": [
    null,
    "Следване"
  ],
  "Graph": [
    null,
    "Диаграма"
  ],
  "Grid": [
    null,
    "Решетка"
  ],
  "Hide": [
    null,
    "Скриване"
  ],
  "Image": [
    null,
    "Изображение"
  ],
  "Input is too short, must be at least one character": [
    "Input is too short, must be at least %(num)d characters",
    "",
    ""
  ],
  "Link": [
    null,
    "Връзка"
  ],
  "Link to a URL on the internet (you can also link to an API)": [
    null,
    "Посочване на връзка към URL адрес в интернет (можете също така да посочите връзка към API)"
  ],
  "Loading...": [
    null,
    "Зареждане...."
  ],
  "Map": [
    null,
    "Карта"
  ],
  "No matches found": [
    null,
    "Няма намерени съвпадения"
  ],
  "Please Confirm Action": [
    null,
    "Моля, потвърдете действието"
  ],
  "Remove": [
    null,
    "Премахване"
  ],
  "Resource uploaded": [
    null,
    "Ресурсът е качен"
  ],
  "Save order": [
    null,
    "Запазване на подредбата"
  ],
  "Saving...": [
    null,
    "Запазване..."
  ],
  "Show more": [
    null,
    "Показване на още"
  ],
  "Start typing…": [
    null,
    "Започнете да пишете..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Има незапазени промени в този формуляр"
  ],
  "There is no API data to load for this resource": [
    null,
    "Няма информация в API за този ресурс"
  ],
  "URL": [
    null,
    "URL адрес"
  ],
  "Unable to authenticate upload": [
    null,
    "Неуспешна проверката за автентичност на качения файл"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Неуспешно зареждане на информацията за качения файл"
  ],
  "Unable to upload file": [
    null,
    "Неуспешно качване на файл"
  ],
  "Unfollow": [
    null,
    "Прекратяване на следването"
  ],
  "Upload": [
    null,
    "Качване"
  ],
  "Upload a file": [
    null,
    "Качване на файл"
  ],
  "Upload a file on your computer": [
    null,
    "Качване файл от Вашия компютър"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "В момента качвате файл. Сигурни ли сте, че искате да излезете от страницата и да прекъснете качването?"
  ],
  "error loading view": [
    null,
    "грешка при зареждането на изгледа"
  ]
}
